pub struct Diagnostic {
pub code: &'static str,
pub error: String,
pub fix: String,
pub example: String,
pub span: Option<Span>,
pub severity: Severity,
pub doc_url: Option<String>,
}Expand description
A diagnostic emitted by the codegen for a resource file.
Fields
code: &'static strerror: Stringfix: Stringexample: Stringspan: Option<Span>severity: Severitydoc_url: Option<String>Implementations
Sourceimpl Diagnostic
impl Diagnostic
Sourcepub fn error(
code: &'static str,
error: impl Into<String>,
fix: impl Into<String>,
example: impl Into<String>,
) -> Self
pub fn error( code: &'static str, error: impl Into<String>, fix: impl Into<String>, example: impl Into<String>, ) -> Self
Construct a diagnostic. Severity and doc_url come from the registry.
In debug builds, panics if code is not in the registry — keeps the
registry authoritative. In release builds, falls back to Severity::Error.