pub fn parse_resource_file(
path: &Path,
) -> Result<ResourceDefinition, ParseError>Expand description
Parse a resource YAML file from disk.
Wraps parse errors with the filename for clearer diagnostics.
pub fn parse_resource_file(
path: &Path,
) -> Result<ResourceDefinition, ParseError>Parse a resource YAML file from disk.
Wraps parse errors with the filename for clearer diagnostics.